/**
 * Marlin 3D Printer Firmware
 * Copyright (c) 2020 MarlinFirmware [https://github.com/MarlinFirmware/Marlin]
 *
 * Based on Sprinter and grbl.
 * Copyright (c) 2011 Camiel Gubbels / Erik van der Zalm
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 */
#pragma once

/**
 * MKS Robin mini (STM32F130VET6) board pin assignments
 */

#if NOT_TARGET(__STM32F1__)
  #error "Oops! Select an STM32F1 board in 'Tools > Board.'"
#elif HOTENDS > 1 || E_STEPPERS > 1
  #error "MKS Robin mini only supports one hotend / E-stepper. Comment out this line to continue."
#endif

#define BOARD_INFO_NAME "Mingda MD-16 MPX_ARM_MINI"

#define BOARD_NO_NATIVE_USB

//
// Release PB4 (Y_ENABLE_PIN) from JTAG NRST role
//
#define DISABLE_DEBUG

//
// EEPROM
//
// Onboard I2C EEPROM
#if NO_EEPROM_SELECTED
  #define I2C_EEPROM
  #define MARLIN_EEPROM_SIZE 0x1000                 // 4KB
  #undef NO_EEPROM_SELECTED
#endif

//#if EITHER(NO_EEPROM_SELECTED, FLASH_EEPROM_EMULATION)
//  #define FLASH_EEPROM_EMULATION
//  #define EEPROM_PAGE_SIZE              (0x800U)  // 2KB
//  #define EEPROM_START_ADDRESS      (0x8000000UL + (STM32_FLASH_SIZE) * 1024UL - (EEPROM_PAGE_SIZE) * 2UL)
//  #define MARLIN_EEPROM_SIZE    EEPROM_PAGE_SIZE  // 2KB
//#endif

#define SPI_DEVICE                             2

//
// Limit Switches
//
#define X_MIN_PIN                           PD6
#define X_MAX_PIN                           PG15
#define Y_MIN_PIN                           PG9
#define Y_MAX_PIN                           PG14
#define Z_MIN_PIN                           PG10
#define Z_MAX_PIN                           PG13

#ifndef FIL_RUNOUT_PIN
  #define FIL_RUNOUT_PIN                    PG11   // MT_DET
#endif

//
// Steppers
//
#define X_ENABLE_PIN                        PD13
#define X_STEP_PIN                          PD12
#define X_DIR_PIN                           PD11

#define Y_ENABLE_PIN                        PG4
#define Y_STEP_PIN                          PG3
#define Y_DIR_PIN                           PG2

#define Z_ENABLE_PIN                        PG7
#define Z_STEP_PIN                          PG6
#define Z_DIR_PIN                           PG5

#define E0_ENABLE_PIN                       PC7
#define E0_STEP_PIN                         PC6
#define E0_DIR_PIN                          PG8

//
// Temperature Sensors
//
//#define TEMP_0_PIN                          PF6   // THERM_E0
#define TEMP_0_PIN                          PB3   // E0 K+
#define TEMP_BED_PIN                        PF7   // THERM_BED


//
// Heaters / Fans
//
#define HEATER_0_PIN                        PB0
#define HEATER_BED_PIN                      PB1

#define FAN_PIN                             PA0   // FAN

//
// SD Card
//
#ifndef SDCARD_CONNECTION
  #define SDCARD_CONNECTION              ONBOARD
#endif

#define SDIO_SUPPORT
#define SDIO_CLOCK                       4500000  // 4.5 MHz
#define SD_DETECT_PIN                       PC5
#define ONBOARD_SPI_DEVICE                     1  // SPI1
#define ONBOARD_SD_CS_PIN                   PC10

//
// LCD / Controller
//
#define BEEPER_PIN                          PE4

/**
 * Note: MKS Robin TFT screens use various TFT controllers.
 * If the screen stays white, disable 'LCD_RESET_PIN'
 * to let the bootloader init the screen.
 */
#if EITHER(HAS_FSMC_GRAPHICAL_TFT, TFT_320x240)
  #define FSMC_CS_PIN                       PD7   
  #define FSMC_RS_PIN                       PG0    /

  #define LCD_USE_DMA_FSMC                        // Use DMA transfers to send data to the TFT
  #define FSMC_DMA_DEV                      DMA2  //?????
  #define FSMC_DMA_CHANNEL               DMA_CH5  //?????

  #define LCD_RESET_PIN                     PF15   // FSMC_RST
  #define LCD_BACKLIGHT_PIN                 PF11
#endif

#if BOTH(NEED_TOUCH_PINS, HAS_FSMC_GRAPHICAL_TFT) || ENABLED(TFT_320x240)
  #define TOUCH_CS_PIN                      PA4   // SPI2_NSS
  #define TOUCH_SCK_PIN                     PA5  // SPI2_SCK
  #define TOUCH_MISO_PIN                    PA6  // SPI2_MISO
  #define TOUCH_MOSI_PIN                    PA7  // SPI2_MOSI
#endif

#if ENABLED(TFT_320x240)                          // TFT32/28
  #define TFT_DRIVER                     ILI9341
  #define TFT_BUFFER_SIZE                  14400
  #define ILI9341_COLOR_RGB
  // YV for normal screen mounting
  #define ILI9341_ORIENTATION  ILI9341_MADCTL_MY | ILI9341_MADCTL_MV
  // XV for 180° rotated screen mounting
  //#define ILI9341_ORIENTATION  ILI9341_MADCTL_MX | ILI9341_MADCTL_MV
#endif

#if ENABLED(TOUCH_SCREEN)
  #ifndef TOUCH_CALIBRATION_X
    #define TOUCH_CALIBRATION_X            12033
  #endif
  #ifndef TOUCH_CALIBRATION_Y
    #define TOUCH_CALIBRATION_Y            -9047
  #endif
  #ifndef TOUCH_OFFSET_X
    #define TOUCH_OFFSET_X                   -30
  #endif
  #ifndef TOUCH_OFFSET_Y
    #define TOUCH_OFFSET_Y                   254
  #endif
#endif
